@@ -1,4 +1,6 @@
+import os.path as osp
 import shutil
+import time
 from pathlib import Path
 
 try:
@@ -7,6 +9,12 @@ except ImportError:
     import json
 
 
+def get_ctime(filename, format=r"%Y%m%d_%H%M%S"):
+    ctime = osp.getctime(filename)
+    ctime = time.localtime(ctime)
+    return time.strftime(format, ctime)
+
+
 def make_dir(path):
     path = Path(path)
     if not path.exists():
